@@ -71,6 +71,8 @@ extern char *MARU_PW;
 #define NT_COMMAND1_TREE_2 "t"
 #define NT_COMMAND1_ID_1 "id"
 #define NT_COMMAND1_ID_2 "i"
+#define NT_COMMAND1_SEARCH_1 "search"
+#define NT_COMMAND1_SEARCH_2 "se"
 
 extern int set_option(int argc, char* argv[]);
 
