@@ -18,26 +18,32 @@
 #ifndef _DISP_H_
 #define _DISP_H_
 #include "ui/disp_win.h"
+#include "_2ch/search_2ch.h"
 
-#define	DISP_STATE_ERROR		(-1)
-#define	DISP_STATE_BOARDMENU	1
-#define	DISP_STATE_THREADTITLE	2
-#define	DISP_STATE_RESLIST		3
-#define	DISP_STATE_EDITOR		4 
-#define	DISP_STATE_HTML_RESULT	5
-#define	DISP_STATE_REFRESH		6
+#define	DISP_STATE_ERROR			(-1)
+#define	DISP_STATE_BOARDMENU		1
+#define	DISP_STATE_THREADTITLE		2
+#define	DISP_STATE_RESLIST			3
+#define	DISP_STATE_EDITOR			4 
+#define	DISP_STATE_HTML_RESULT		5
+#define	DISP_STATE_REFRESH			6
+#define	DISP_STATE_SEARCH_THREAD	7
 
 
 extern int disp_board_menu(nt_window_tp wp, 
-		nt_2ch_model_tp modelp);
+		nt_2ch_model_tp modelp, nt_2ch_selected_item_tp selectp);
 extern int disp_threadlist(nt_window_tp wp, 
-		nt_2ch_model_tp modelp, void *usr_db_handle);
+		nt_2ch_selected_item_tp selectp, void *usr_db_handle);
 extern int disp_reslist(nt_window_tp wp, 
-		nt_2ch_model_tp modelp, void *usr_db_handle);
+		nt_2ch_selected_item_tp selectp, void *usr_db_handle);
+extern int disp_thread_search(nt_window_tp wp, 
+		int prev_state, nt_link_tp thread_list, 
+		nt_searched_thread_tp *sel_threadpp);
 extern void free_board_menu_ctx(void *ptr);
 extern void init_threadlist_ctx(void *ptr);
 extern void free_threadlist_ctx(void *ptr);
 extern void free_reslist_ctx(void *ptr);
+extern void free_search_thread_ctx(void *ptr);
 extern BOOL disp_editor(nt_write_data_tp writep);
 extern int disp_html_result(nt_write_data_tp writep);
 
