@@ -25,6 +25,7 @@
 #include <locale.h>
 #include <iconv.h>
 #include <netinet/in.h>
+#include <assert.h>
 
 #include "env.h"
 #include "error.h"
@@ -37,6 +38,7 @@
 #include "utils/nt_usr_db.h"
 #include "_2ch/_2ch.h"
 #include "_2ch/maru_2ch.h"
+#include "_2ch/search_2ch.h"
 #include "ui/disp.h"
 #include "ui/disp_win.h"
 #include "ui/disp_string.h"
@@ -45,7 +47,10 @@
 
 static int draw_title(WINDOW *wp, wchar_t *title, attr_t attr);
 static BOOL DoLoop(WINDOW *scrp, void *db_handle);
-static void print_error(WINDOW *wp, wchar_t *msg);
+static void print_error(WINDOW *wp, const wchar_t *msg);
+static BOOL set_sel_item(nt_2ch_model_tp modelp,
+			nt_2ch_selected_item_tp sel_itemp, 
+			nt_searched_thread_tp sel_threadp, const wchar_t** errorpp);
 
 
 int main(int argc, char *argv[])
@@ -117,14 +122,21 @@ static BOOL DoLoop(WINDOW *scrp, void *db_handle)
 	nt_window_tp bwinp = NULL;
 	nt_window_tp twinp = NULL;
 	nt_window_tp rwinp = NULL;
+	nt_window_tp search_winp = NULL;
 	char buf[256];
 	wchar_t wch, *title;
-	wchar_t *status_msg = NULL;
+	const wchar_t *status_msg = NULL;
 	BOOL result = FALSE;
 	nt_write_data_tp writep = NULL;
 	nt_maru_2ch_tp marup = NULL;
 	nt_cookie_tp cookiep;
-
+	nt_link_tp linkp;
+	char *search;
+	nt_searched_thread_tp sel_threadp;
+	nt_2ch_selected_item_t sel_items;
+	nt_2ch_selected_item_t sel_items_tmp;
+	
+	
 	disp_state = DISP_STATE_BOARDMENU; 
 	cookiep = nt_load_cookies(USR_COOKIE_PATH);
 
@@ -155,11 +167,11 @@ static BOOL DoLoop(WINDOW *scrp, void *db_handle)
 			draw_title(scrp, L"板一覧", WA_REVERSE);
 			if(!nt_disp_win_move(scrp, bwinp, LINES-1, COLS, 1, 0))
 				goto END_WHILE;
-			state = disp_board_menu(bwinp, app_2ch_modelp);
+			state = disp_board_menu(bwinp, app_2ch_modelp, &sel_items);
 			if(DISP_STATE_ERROR == state){
 				goto END_WHILE;
 			}else if(DISP_STATE_THREADTITLE == state){
-				if(nt_read_board(app_2ch_modelp)){
+				if(nt_read_board(&sel_items)){
 					disp_state = state;
 					if(twinp->data){
 						free_threadlist_ctx(twinp->data);
@@ -170,26 +182,30 @@ static BOOL DoLoop(WINDOW *scrp, void *db_handle)
 				}else{
 					print_error(scrp, NT_ERR_MSG_COUDLNOT_READ_BOARD);
 				}
+			}else if(state == DISP_STATE_SEARCH_THREAD){
+				state = DISP_STATE_BOARDMENU;
+				disp_state = DISP_STATE_SEARCH_THREAD;
+				ch = NT_KEY_NONE;
+				continue;
 			}
 			break;
 		case DISP_STATE_THREADTITLE:
 			werase(twinp->wp);
 			twinp->key = ch;
 			twinp->status_msg = NULL;
-			title = app_2ch_modelp->selected_boardp->name;
+			title = sel_items.selected_boardp->name;
 			draw_title(scrp, title, WA_REVERSE);
 			if(!nt_disp_win_move(scrp, twinp, LINES-1, COLS, 1, 0))
 				goto END_WHILE;
-			state = disp_threadlist(twinp, app_2ch_modelp, db_handle);
+			state = disp_threadlist(twinp, &sel_items, db_handle);
 			if(DISP_STATE_ERROR == state){
 				goto END_WHILE;
-			}else {
-				if(DISP_STATE_BOARDMENU == state){
+			}else if(DISP_STATE_BOARDMENU == state){
 					disp_state = state;
 					ch = NT_KEY_NONE;
 					continue;
-				}else if(DISP_STATE_REFRESH == state){
-					if(nt_read_board(app_2ch_modelp)){
+			}else if(DISP_STATE_REFRESH == state){
+					if(nt_read_board(&sel_items)){
 						if(twinp->data){
 							free_threadlist_ctx(twinp->data);
 							twinp->data = NULL;
@@ -200,8 +216,8 @@ static BOOL DoLoop(WINDOW *scrp, void *db_handle)
 					}else{
 						status_msg = NT_ERR_MSG_COUDLNOT_READ_BOARD;
 					}
-				}else if(DISP_STATE_RESLIST == state){
-					if(!nt_read_thread(app_2ch_modelp)){
+			}else if(DISP_STATE_RESLIST == state){
+					if(!nt_read_thread(&sel_items)){
 						wclear(scrp);
 						ch = NT_KEY_NONE;
 						continue;
@@ -216,25 +232,29 @@ static BOOL DoLoop(WINDOW *scrp, void *db_handle)
 					disp_state = state;
 					ch = NT_KEY_NONE;
 					continue;
-				}else{
+			}else if(DISP_STATE_SEARCH_THREAD == state){
+				state = DISP_STATE_THREADTITLE;
+				disp_state = DISP_STATE_SEARCH_THREAD;
+				ch = NT_KEY_NONE;
+				continue;
+			}else{
 					status_msg = twinp->status_msg;
-				}
 			}
 			break;
 		case DISP_STATE_RESLIST:
 			werase(rwinp->wp);
-			title = app_2ch_modelp->selected_threadp->name;
+			title = sel_items.selected_threadp->name;
 			num = draw_title(scrp, title, WA_REVERSE);
 			if(!nt_disp_win_move(scrp, rwinp, 
 						LINES - num, COLS, num, 0))
 				goto END_WHILE;
 			rwinp->key = ch;
-			state = disp_reslist(rwinp, app_2ch_modelp, db_handle);
+			state = disp_reslist(rwinp, &sel_items, db_handle);
 			if(DISP_STATE_ERROR == state){
 				goto END_WHILE;
 			}else if(state == DISP_STATE_REFRESH){
 					ch = NT_KEY_NONE;
-					if(!nt_read_thread(app_2ch_modelp)){
+					if(!nt_read_thread(&sel_items)){
 						status_msg = NT_ERR_MSG_REFRESH_THREAD_FAILED;
 						wclear(scrp);
 						continue;
@@ -246,6 +266,11 @@ static BOOL DoLoop(WINDOW *scrp, void *db_handle)
 					status_msg = NT_INFO_REFRESH_THREAD_SUCCESS;
 					wclear(scrp);
 					continue;
+			}else if(state == DISP_STATE_SEARCH_THREAD){
+				state = DISP_STATE_RESLIST;
+				disp_state = DISP_STATE_SEARCH_THREAD;
+				ch = NT_KEY_NONE;
+				continue;
 			}else if(state != DISP_STATE_RESLIST){
 				disp_state = state;
 				ch = NT_KEY_NONE;
@@ -263,7 +288,7 @@ static BOOL DoLoop(WINDOW *scrp, void *db_handle)
 			if(disp_editor(writep)){
 				if(marup && !marup->sid)
 					get_session_id(marup);
-				if(nt_write_msg(app_2ch_modelp, 
+				if(nt_write_msg(&sel_items, 
 						writep, cookiep, marup)){
 					disp_state = DISP_STATE_HTML_RESULT;
 					continue;
@@ -275,17 +300,17 @@ static BOOL DoLoop(WINDOW *scrp, void *db_handle)
 		case DISP_STATE_HTML_RESULT:
 			nresult = disp_html_result(writep);
 			if(0 == nresult){
-				if(!nt_read_thread(app_2ch_modelp))
+				if(!nt_read_thread(&sel_items))
 					break;
 				if(rwinp->data){
 					free_reslist_ctx(rwinp->data);
 					rwinp->data = NULL;
 				}
 			}else if(1 == nresult){
-				if(nt_write_msg(app_2ch_modelp, 
+				if(nt_write_msg(&sel_items, 
 						writep, cookiep, marup)){
 					if(0 == disp_html_result(writep)){
-						if(!nt_read_thread(app_2ch_modelp))
+						if(!nt_read_thread(&sel_items))
 							break;
 						if(rwinp->data){
 							free_reslist_ctx(rwinp->data);
@@ -299,6 +324,46 @@ static BOOL DoLoop(WINDOW *scrp, void *db_handle)
 			status_msg = writep->status_msg;
 			wclear(scrp);
 			continue;
+		case DISP_STATE_SEARCH_THREAD:
+			draw_title(scrp, L"全板検索", WA_REVERSE);
+			if(!search_winp)
+				search_winp = nt_disp_win_alloc(
+						scrp, LINES-1, COLS, 1, 0, buf);
+			if(!search_winp)
+				goto END_WHILE;
+			search_winp->key = ch;
+			linkp = NULL;
+			if(nt_get_search_text(buf, &search)){
+				if(search){
+					linkp = nt_search_all_board(
+							app_2ch_modelp, search, &status_msg);
+					free(search);
+					buf[0] = '\0';
+				}
+			}
+			disp_state = disp_thread_search(search_winp, 
+					state, linkp, &sel_threadp);
+			ch = NT_KEY_NONE;
+			if(sel_threadp){
+				if(set_sel_item(app_2ch_modelp,
+						&sel_items_tmp, sel_threadp, &status_msg)){
+					disp_state = DISP_STATE_RESLIST;
+					sel_items = sel_items_tmp;
+					if(rwinp->data){
+						free_reslist_ctx(rwinp->data);
+						rwinp->data = NULL;
+					}
+					if(twinp->data){
+						free_threadlist_ctx(twinp->data);
+						twinp->data = NULL;
+					}
+				}
+				continue;
+			}
+			if(disp_state != DISP_STATE_SEARCH_THREAD){
+				continue;
+			}
+			break;
 		default:
 		 	goto END_WHILE;
 		}/* end switch*/
@@ -365,12 +430,65 @@ END_WHILE:
 	free_board_menu_ctx(bwinp->data);
 	free_threadlist_ctx(twinp->data);
 	free_reslist_ctx(rwinp->data);
+	if(search_winp){
+		if(search_winp->data)
+			free_search_thread_ctx(search_winp->data);
+		nt_disp_win_free(search_winp);
+	}
 	nt_disp_win_free(bwinp);
 	nt_disp_win_free(twinp);
 	nt_disp_win_free(rwinp);
 	return result;
 }
 
+static BOOL set_sel_item(nt_2ch_model_tp modelp,
+			nt_2ch_selected_item_tp sel_itemp, 
+			nt_searched_thread_tp sel_threadp, const wchar_t** errorpp)
+{
+	nt_category_tp categoryp;
+	nt_board_tp boardp;
+	nt_thread_tp threadp;
+	
+	assert(sel_threadp);
+	assert(sel_threadp->board_name);
+	assert(sel_threadp->dat_name);
+	
+	boardp = nt_get_board_by_name(
+			modelp, sel_threadp->board_name, &categoryp);
+	if(!boardp || !categoryp){
+		*errorpp = L"板情報が見つかりませんでした";
+		return FALSE;
+	}
+		
+	sel_itemp->selected_categoryp = categoryp;
+	sel_itemp->selected_boardp = boardp;
+	sel_itemp->selected_threadp = NULL;
+	
+	if(!boardp->threadlistp){
+		if(!nt_read_board(sel_itemp) 
+				|| !boardp->threadlistp){
+			*errorpp = L"板が開けませんでした";
+			return FALSE;
+		}
+	}
+	threadp = nt_get_thread_by_dat_name(
+			boardp->threadlistp, sel_threadp->dat_name);
+	if(!threadp){
+		*errorpp = L"スレッド情報が見つかりませんでした";
+		return FALSE;
+	}
+	
+	sel_itemp->selected_threadp = threadp;
+	
+	if(!nt_read_thread(sel_itemp)){
+		*errorpp = L"スレッドが開けませんでした";
+		return FALSE;
+	}
+	
+	return TRUE;
+}
+
+
 static int draw_title(WINDOW *wp, wchar_t *title, attr_t attr)
 {
 	move(0,0);
@@ -387,7 +505,7 @@ static int draw_title(WINDOW *wp, wchar_t *title, attr_t attr)
 
 
 
-static void print_error(WINDOW *wp, wchar_t *msg)
+static void print_error(WINDOW *wp, const wchar_t *msg)
 {
 	move(LINES-1,0);
 	nt_add_wstr(wp, msg, 0);
