@@ -232,8 +232,11 @@ static char* merge_cookie(const char *val1, const char *val2)
 				kvp = nt_key_value_alloc(key, value);
 				if(linkp){
 					wrk_linkp = nt_link_find(linkp, kvp, cmp_link_func);
-					if(wrk_linkp)
-						nt_link_remove(linkp, wrk_linkp);
+					if(wrk_linkp){
+						linkp = nt_link_remove2(linkp, wrk_linkp);
+						kvp_free_func(wrk_linkp->data);
+						free(wrk_linkp);
+					}
 				}
 				wrk_linkp = nt_link_add_data(linkp, kvp);
 				if(!linkp)
@@ -280,11 +283,9 @@ static char* merge_cookie(const char *val1, const char *val2)
 				if(linkp){
 					wrk_linkp = nt_link_find(linkp, kvp, cmp_link_func);
 					if(wrk_linkp){
-						wrk_linkp = nt_link_remove(linkp, wrk_linkp);
-						if(wrk_linkp){
-							kvp_free_func(wrk_linkp->data);
-							free(wrk_linkp);
-						}
+						linkp = nt_link_remove2(linkp, wrk_linkp);
+						kvp_free_func(wrk_linkp->data);
+						free(wrk_linkp);
 					}
 				}
 				wrk_linkp = nt_link_add_data(linkp, kvp);
