@@ -225,7 +225,7 @@ ERROR_TRAP:
 
 BOOL nt_http_get(const char *url, const char *out_path,
 		const char *referer, const char *user_agent, 
-		nt_link_tp extend_headers, BOOL range)
+		nt_link_tp extend_headers, BOOL range, BOOL ignore_cache)
 {
 	nt_socket_tp socketp;
 	int fd = -1, sockfd;
@@ -244,8 +244,10 @@ BOOL nt_http_get(const char *url, const char *out_path,
 	nt_http_header_tp headerp = nt_http_init_header(url);
 	if(headerp == NULL)
 		return FALSE;
-	if(!nt_http_init_header2(headerp, out_path))
-		return FALSE;
+	if(!ignore_cache){
+		if(!nt_http_init_header2(headerp, out_path))
+			return FALSE;
+	}
 
 	strcpy(data, "GET ");
 	strcat(data, headerp->param);
@@ -366,7 +368,8 @@ BOOL nt_http_get(const char *url, const char *out_path,
 				}
 			}while(nread > 0);
 		}
-		nt_http_save_response_header(out_path, responsep);
+		if(!ignore_cache)
+			nt_http_save_response_header(out_path, responsep);
 		result = TRUE;
 		break;
 	case 206: /* Partial content */
@@ -393,7 +396,8 @@ BOOL nt_http_get(const char *url, const char *out_path,
 				break;
 			}
 		}while(nread > 0);
-		nt_http_save_response_header(out_path, responsep);
+		if(!ignore_cache)
+			nt_http_save_response_header(out_path, responsep);
 		result = TRUE;
 		break;
 	case 304: /* Not Modified */
@@ -414,7 +418,7 @@ ERROR_TRAP:
 	nt_http_free_response_header(responsep);
 	if(retry && range)
 		return nt_http_get(url, out_path, referer, user_agent, 
-				extend_headers, FALSE);
+				extend_headers, FALSE, ignore_cache);
 
 	return result;
 }
