@@ -39,6 +39,7 @@
 #define NT_CMD_JMP_NEW 2
 #define NT_CMD_TREE 3
 #define NT_CMD_ID 4
+#define NT_CMD_SEARCH_THREAD 5
 
 typedef struct tag_ctx_reslist_t *ctx_reslist_tp;
 typedef struct tag_ctx_reslist_t
@@ -73,7 +74,7 @@ typedef struct tag_res_data_t {
 	int id_num;
 }res_data_t;
 
-static ctx_reslist_tp init_context(nt_2ch_model_tp modelp, 
+static ctx_reslist_tp init_context(nt_2ch_selected_item_tp selectp, 
 			void *usr_db_handle);
 static BOOL reslist_clone(nt_thread_tp threadp, ctx_reslist_tp ctxp);
 static void int_ptr_free(void *ptr);
@@ -99,7 +100,7 @@ static int get_id_num(ctx_reslist_tp ctxp, const wchar_t *misc);
 static BOOL set_res_header(ctx_reslist_tp ctxp, res_data_tp res_datap,
 				wchar_t *buf, size_t buf_len);
 
-int disp_reslist(nt_window_tp wp, nt_2ch_model_tp modelp,
+int disp_reslist(nt_window_tp wp, nt_2ch_selected_item_tp selectp,
 	void *usr_db_handle)
 {
 	ctx_reslist_tp ctxp, child_ctxp;
@@ -128,7 +129,7 @@ int disp_reslist(nt_window_tp wp, nt_2ch_model_tp modelp,
 
 	ctxp = (ctx_reslist_tp)wp->data;
 	if(!ctxp){
-		ctxp = init_context(modelp, usr_db_handle);
+		ctxp = init_context(selectp, usr_db_handle);
 		if(!ctxp)
 			return DISP_STATE_ERROR;
 		wp->data = ctxp;
@@ -396,6 +397,8 @@ int disp_reslist(nt_window_tp wp, nt_2ch_model_tp modelp,
 		assert(wp->cmd_param);
 		cmd = parse_cmd1(wp->cmd_param, &state, &endp);
 		switch(cmd){
+		case NT_CMD_SEARCH_THREAD:
+			return DISP_STATE_SEARCH_THREAD;
 		case NT_CMD_WRITE:
 			return state;
 		case NT_CMD_JMP_NEW:
@@ -874,19 +877,24 @@ static int parse_cmd1(const char *param, int *statep, const char **end)
 	}else if(0 == strncmp(NT_COMMAND1_ID_1, start,len) ||
 		0 == strncmp(NT_COMMAND1_ID_2, start,len)){
 		return NT_CMD_ID;
+	}else if(0 == strncmp(NT_COMMAND1_SEARCH_1,param,
+			strlen(NT_COMMAND1_SEARCH_1)) ||
+		0 == strncmp(NT_COMMAND1_SEARCH_2,param,
+			strlen(NT_COMMAND1_SEARCH_2))){
+		return NT_CMD_SEARCH_THREAD;
 	}
 	return NT_CMD_NONE;
 }
 
-static ctx_reslist_tp init_context(nt_2ch_model_tp modelp,
+static ctx_reslist_tp init_context(nt_2ch_selected_item_tp selectp,
 	void *usr_db_handle)
 {
 	ctx_reslist_tp ctxp;
 	nt_board_tp boardp;
 	nt_thread_tp threadp;
 
-	boardp = modelp->selected_boardp;
-	threadp = modelp->selected_threadp;
+	boardp = selectp->selected_boardp;
+	threadp = selectp->selected_threadp;
 	assert(boardp && threadp);
 
 	ctxp = (ctx_reslist_tp)calloc(1,sizeof(ctx_reslist_t));
@@ -989,6 +997,10 @@ static BOOL reslist_clone(nt_thread_tp threadp, ctx_reslist_tp ctxp)
 					&datap->cite_num_list);
 				if(!datap->resp->name || !datap->resp->mail ||
 						!datap->resp->misc || !datap->resp->msg){
+					if(datap->resp->name)free(datap->resp->name);
+					if(datap->resp->mail)free(datap->resp->mail);
+					if(datap->resp->misc)free(datap->resp->misc);
+					if(datap->resp->msg)free(datap->resp->msg);
 					free(datap->resp);
 					free(datap);
 				}else{
