@@ -61,6 +61,7 @@ typedef struct tag_ctx_threadlist_t
 #define NT_CMD_SORT_READ 2
 #define NT_CMD_SORT_UNREAD 3
 #define NT_CMD_DEL_THREAD_LOG 4
+#define NT_CMD_SEARCH_THREAD 5
 
 static int parse_cmd1(const char *param);
 static int get_thread_index_by_seqno(nt_link_tp linkp, int seq_no);
@@ -68,7 +69,7 @@ static BOOL search_line_asc(regex_t *regexp,
 				nt_link_tp threadlistp, int *sel_thread_no);
 static BOOL search_line_desc(regex_t *regexp, 
 				nt_link_tp threadlistp, int *sel_thread_no);
-static ctx_threadlist_tp init_context(nt_2ch_model_tp modelp);
+static ctx_threadlist_tp init_context(nt_2ch_selected_item_tp selectp);
 static int merge_untracked_thread_log(nt_board_tp boardp,
 		nt_link_tp *disp_thread_listpp, nt_link_tp log_list);
 
@@ -94,8 +95,8 @@ static void sort_thread_title(int sort_type, ctx_threadlist_tp ctxp)
 	}
 }
 
-int disp_threadlist(nt_window_tp wp, nt_2ch_model_tp modelp,
-				void *db_handle)
+int disp_threadlist(nt_window_tp wp, nt_2ch_selected_item_tp selectp,
+				 void *db_handle)
 {
 	ctx_threadlist_tp ctxp;
 	nt_board_tp boardp;
@@ -115,14 +116,14 @@ int disp_threadlist(nt_window_tp wp, nt_2ch_model_tp modelp,
 
 	ctxp = (ctx_threadlist_tp)wp->data;
 	if(!ctxp){
-		ctxp = init_context(modelp);
+		ctxp = init_context(selectp);
 		if(!ctxp)
 			return DISP_STATE_ERROR;
 		wp->data = ctxp;
 		sort = TRUE;
 	}
 
-	boardp = modelp->selected_boardp;
+	boardp = selectp->selected_boardp;
 
 	if(!ctxp->thread_data_list){
 		ctxp->thread_data_list =
@@ -242,6 +243,8 @@ int disp_threadlist(nt_window_tp wp, nt_2ch_model_tp modelp,
 				}while(clistp != linkp);
 				nt_all_link_free(linkp, NULL);
 				return DISP_STATE_REFRESH;
+			case NT_CMD_SEARCH_THREAD:
+				return DISP_STATE_SEARCH_THREAD;
 			default:
 				break;
 			}
@@ -338,7 +341,7 @@ int disp_threadlist(nt_window_tp wp, nt_2ch_model_tp modelp,
 				ctxp->cursor_pos);
 		if(!threadp)
 			break;
-		nt_set_selected_thread(modelp, threadp);
+		nt_set_selected_thread(selectp, threadp);
 		return DISP_STATE_RESLIST;
 	}
 
@@ -414,7 +417,7 @@ int disp_threadlist(nt_window_tp wp, nt_2ch_model_tp modelp,
 	return DISP_STATE_THREADTITLE; 
 }
 
-static ctx_threadlist_tp init_context(nt_2ch_model_tp modelp)
+static ctx_threadlist_tp init_context(nt_2ch_selected_item_tp selectp)
 {
 	ctx_threadlist_tp ctxp;
 	nt_board_tp boardp;
@@ -423,7 +426,7 @@ static ctx_threadlist_tp init_context(nt_2ch_model_tp modelp)
 	if(!ctxp)
 		return NULL;
 
-	boardp = modelp->selected_boardp;
+	boardp = selectp->selected_boardp;
 	ctxp->thread_num = nt_link_num(boardp->threadlistp);
 	ctxp->tracked_thread_num = ctxp->thread_num;
 
@@ -647,7 +650,12 @@ static int parse_cmd1(const char *param)
 	const char *start, *end;
 
 	assert(param);
-	if(0 == strncmp(NT_COMMAND1_SORT_1, param,
+	if(0 == strncmp(NT_COMMAND1_SEARCH_1,param,
+			strlen(NT_COMMAND1_SEARCH_1)) ||
+		0 == strncmp(NT_COMMAND1_SEARCH_2,param,
+			strlen(NT_COMMAND1_SEARCH_2))){
+		return NT_CMD_SEARCH_THREAD;
+	}else if(0 == strncmp(NT_COMMAND1_SORT_1, param,
 			strlen(NT_COMMAND1_SORT_1))){
 		offset = strlen(NT_COMMAND1_SORT_1);
 	}else if( 0 == strncmp(NT_COMMAND1_SORT_2, param,
